@@ -20,7 +20,7 @@ import json
 import collections.abc
 
 from .logger import get_logger
-from .client_util import is_dict_contains_fields, get_boolean_value_for_env_var
+from .client_util import is_dict_contains_fields
 from .client_exceptions import MonaExportException
 
 
